==> xh_framework-0.0.1.tar.gz: lib/com/xh/base/xh_widget.dart <==
import 'package:flutter/material.dart';
import 'package:xh_framework/com/xh/widget/loader_widget.dart';
import 'package:fluttertoast/fluttertoast.dart';

typedef void OnTapCallback(int action, dynamic data);

abstract class XHStatefulWidget<Model> extends StatefulWidget {
  XHStatefulWidget({this.onTap, this.data}) : super();
  final Model data;
  final OnTapCallback onTap;

  State<XHStatefulWidget> createState();
}

abstract class XHStatefulWidgetState<T extends XHStatefulWidget, Model>
    extends State<XHStatefulWidget> {
  XHStatefulWidgetState({this.data});

  final Model data;

  void onChildTap(int action, [dynamic data]) {
    if (widget.onTap != null) {
      widget.onTap(action, data);
    }
  }

  void showLoader() {
    showDialog(
        context: context,
        builder: (context) {
          return new LoaderWidget('正在加载...');
        });
  }

  void showToast(String message) {
    Fluttertoast.showToast(msg: message);
  }

  void closeLoader() {
    Navigator.of(context).pop();
  }
}

// ignore: must_be_immutable
abstract class XHStatelessWidget<T> extends StatelessWidget {
  XHStatelessWidget({this.onTap, this.data});

  final T data;
  final OnTapCallback onTap;

  BuildContext context;

  void onChildTap(int action, [dynamic data]) {
    if (onTap != null) {
      onTap(action, data);
    }
  }

  @override
  Widget build(BuildContext context) {
    this.context = context;
    return null;
  }

  void showLoader() {
    showDialog(
        context: context,
        builder: (context) {
          return new LoaderWidget('正在加载...');
        });
  }

  void showToast(String message) {
    Fluttertoast.showToast(msg: message);
  }

  void closeLoader() {
    Navigator.of(context).pop();
  }
}

==> xh_framework-0.0.3.tar.gz: lib/com/xh/base/xh_widget.dart <==
import 'package:flutter/material.dart';
import 'package:xh_framework/com/xh/callback/on_tap_callback.dart';
import 'package:xh_framework/com/xh/widget/loader_widget.dart';
import 'package:fluttertoast/fluttertoast.dart';


abstract class XHStatefulWidget<Model> extends StatefulWidget {
  XHStatefulWidget({this.onTap, this.data}) : super();
  final Model data;
  final OnTapCallback onTap;

  State<XHStatefulWidget> createState();
}

abstract class XHStatefulWidgetState<T extends XHStatefulWidget, Model>
    extends State<XHStatefulWidget> {
  XHStatefulWidgetState({this.data});

  final Model data;

  void onChildTap(int action, [dynamic data]) {
    if (widget.onTap != null) {
      widget.onTap(action, data);
    }
  }

  void showLoader() {
    showDialog(
        context: context,
        builder: (context) {
          return new LoaderWidget('正在加载...');
        });
  }

  void showToast(String message) {
    Fluttertoast.showToast(msg: message);
  }

  void closeLoader() {
    Navigator.of(context).pop();
  }
}

// ignore: must_be_immutable
abstract class XHStatelessWidget<T> extends StatelessWidget {
  XHStatelessWidget({this.onTap, this.data});

  final T data;
  final OnTapCallback onTap;


  void onChildTap(int action, [dynamic data]) {
    if (onTap != null) {
      onTap(action, data);
    }
  }


  void showLoader(BuildContext context) {
    showDialog(
        context: context,
        builder: (context) {
          return new LoaderWidget('正在加载...');
        });
  }

  void showToast(String message) {
    Fluttertoast.showToast(msg: message);
  }

  void closeLoader(BuildContext context) {
    Navigator.of(context).pop();
  }
}
